#!/usr/bin/python
# -*- coding: utf-8 -*-

# SàT: a XMPP client
# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014 Jérôme Poisson (goffi@goffi.org)

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os.path
try:
    from xdg import BaseDirectory
except ImportError:
    # Catch JS runtime error while using Libervia
    BaseDirectory = None


class Const(object):

    ## Application ##
    APP_NAME = u'Salut à Toi'
    APP_NAME_SHORT = u'SàT'
    APP_NAME_FULL = u'%s (%s)' % (APP_NAME_SHORT, APP_NAME)
    APP_VERSION = u'0.4.1D'  # Please add 'D' at the end for dev versions
    APP_URL = 'http://salut-a-toi.org'


    ## Parameters ##
    NO_SECURITY_LIMIT = -1
    INDIVIDUAL = "individual"
    GENERAL = "general"


    ## Profile and entities ##
    PROF_KEY_NONE = '@NONE@'
    PROF_KEY_DEFAULT = '@DEFAULT@'
    ENTITY_ALL = '@ALL@'
    ENTITY_LAST_RESOURCE = 'LAST_RESOURCE'
    ENTITY_CAP_HASH = 'CAP_HASH'


    ## Configuration ##
    if BaseDirectory:  # skipped when imported from Libervia browser_side

        ## Configuration ##
        DEFAULT_CONFIG = {
            'media_dir': '/usr/share/sat/media',
            'pid_dir': '/tmp',
            'log_dir': BaseDirectory.save_data_path('sat'),
        }

        # XXX: tmp update code, will be removed in the future
        # When you remove this, please add that in DEFAULT_CONFIG:
        # 'local_dir': BaseDirectory.save_data_path('sat'),
        # and also remove sat.memory.memory.Memory.__fixLocalDir
        DEFAULT_LOCAL_DIR = BaseDirectory.save_data_path('sat')

        # List of the configuration filenames sorted by ascending priority
        CONFIG_FILES = [(os.path.expanduser(path) + 'sat.conf') for path in \
                        ['/etc/', '~/', '~/.', '', '.'] + \
                        ['%s/' % path for path in list(BaseDirectory.load_config_paths('sat'))]
                       ]


    ## Plugins ##
    # names of widely used plugins
    TEXT_CMDS = 'TEXT-COMMANDS'


    ## Logging ##
    LOG_BACKEND_STANDARD = 'standard'
    LOG_BACKEND_TWISTED = 'twisted'
    LOG_BACKEND_BASIC = 'basic'
    LOG_BASE_LOGGER = 'root'
    LOG_OPT_PREFIX = 'log_'
    # (option_name, default_value) tuples
    LOG_OPT_COLORS = ('colors', 'true')
    LOG_OPT_LEVEL = ('level', 'info')


    ## Misc ##
    SAVEFILE_DATABASE = "sat.db"
    IQ_SET = '/iq[@type="set"]'
    ENV_PREFIX = 'SAT_' # Prefix used for environment variables


    ## ANSI escape sequences ##
    # XXX: used for logging
    # XXX: there will be probably moved in a dedicated module in the future
    ANSI_RESET = '\033[0m'
    ANSI_NORMAL_WEIGHT = '\033[22m'
    ANSI_FG_BLACK, ANSI_FG_RED, ANSI_FG_GREEN, ANSI_FG_YELLOW, ANSI_FG_BLUE, ANSI_FG_MAGENTA, ANSI_FG_CYAN, ANSI_FG_WHITE = ('\033[3%dm' % nb for nb in xrange(8))
    ANSI_BOLD = '\033[1m'
    ANSI_BLINK = '\033[5m'
    ANSI_BLINK_OFF = '\033[25m'
